@@ -3,7 +3,9 @@ use warnings;
 package Dist::Zilla::MintingProfile::Author::ETHER;
 # ABSTRACT: Mint distributions like ETHER does
 # vim: set ts=8 sw=4 tw=78 et :
-our $VERSION = '0.086';
+
+our $VERSION = '0.087';
+
 use Moose;
 with 'Dist::Zilla::Role::MintingProfile';
 use File::ShareDir;
@@ -40,7 +42,7 @@ Dist::Zilla::MintingProfile::Author::ETHER - Mint distributions like ETHER does
 
 =head1 VERSION
 
-version 0.086
+version 0.087
 
 =head1 SYNOPSIS
 
@@ -79,6 +81,12 @@ bundle).
 You will be prompted to create a repository on github immediately; if you
 decline, you must create one manually before you do your first C<push>.
 
+=item *
+
+C<default>
+
+Presently the same as C<github>. Available since version 0.087.
+
 =back
 
 =head1 SUPPORT
