@@ -1,10 +1,12 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.085-10-ge20fdbb
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.086-14-gecaea46
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sw=4 tw=78 et :
-our $VERSION = '0.086';
+
+our $VERSION = '0.087';
+
 use Moose;
 with
     'Dist::Zilla::Role::PluginBundle::Easy',
@@ -76,7 +78,7 @@ has changes_version_columns => (
 # configs are applied when plugins match ->isa($key) or ->does($key)
 my %extra_args = (
     'Dist::Zilla::Plugin::MakeMaker' => { 'eumm_version' => '0' },
-    'Dist::Zilla::Plugin::ModuleBuildTiny' => { ':version' => '0.004' },
+    'Dist::Zilla::Plugin::ModuleBuildTiny' => { ':version' => '0.009', version_method => 'conservative' },
     'Dist::Zilla::Plugin::MakeMaker::Fallback' => { ':version' => '0.012' },
     # default_jobs is no-op until Dist::Zilla 5.014
     'Dist::Zilla::Role::TestRunner' => { default_jobs => 9 },
@@ -166,7 +168,7 @@ sub configure
         'MetaTests',
         [ 'Test::CPAN::Changes' => { ':version' => '0.008' } ],
         'Test::ChangesHasContent',
-        [ 'Test::MinimumVersion' => { ':version' => '2.000003', max_target_perl => '5.008001' } ],
+        [ 'Test::MinimumVersion' => { ':version' => '2.000003', max_target_perl => '5.006' } ],
         'PodSyntaxTests',
         'PodCoverageTests',
         [ 'Test::PodSpelling'   => { ':version' => '2.006001' } ],
@@ -362,7 +364,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.086
+version 0.087
 
 =head1 SYNOPSIS
 
@@ -372,8 +374,10 @@ In your F<dist.ini>:
 
 =head1 DESCRIPTION
 
-This is a L<Dist::Zilla> plugin bundle. It is approximately equivalent to the
-following F<dist.ini> (following the preamble):
+=for stopwords optimizations
+
+This is a L<Dist::Zilla> plugin bundle. It is I<very approximately> equal to the
+following F<dist.ini> (following the preamble), minus some optimizations:
 
     ;;; VersionProvider
     [RewriteVersion::Transitional]
@@ -381,6 +385,7 @@ following F<dist.ini> (following the preamble):
     fallback_version_provider = Git::NextVersion
     version_regexp = ^v([\d._]+)(-TRIAL)?$
 
+
     ;;; BeforeBuild
     [PromptIfStale / stale modules, build]
     phase = build
@@ -404,6 +409,7 @@ following F<dist.ini> (following the preamble):
     [FileFinder::ByName / ExtraTestFiles]
     dir = xt
 
+
     ;;; Gather Files
     [Git::GatherDir]
     :version = 2.016
@@ -520,6 +526,7 @@ following F<dist.ini> (following the preamble):
     :version = 0.004
     order_by = commits
 
+
     ;;; Register Prereqs
     [AutoPrereqs]
     [Prereqs::AuthorDeps]
