@@ -2,7 +2,7 @@ package # hide from PAUSE
     Helper;
 
 use parent 'Exporter';
-our @EXPORT = qw(all_plugins_in_prereqs);
+our @EXPORT = qw(@REMOVED_PLUGINS assert_no_git all_plugins_in_prereqs);
 
 use Test::More;
 use Test::Deep;
@@ -19,6 +19,33 @@ delete $ENV{DZIL_AIRPLANE};
     sub _pause_config { 'URMOM', 'mysekritpassword' }
 }
 
+# plugins to always remove from test dists, as they use git or the network
+# Our files are copied into source, so Git::GatherDir doesn't see them and
+# besides, we would like to run these tests at install time too!
+our @REMOVED_PLUGINS = qw(
+    Git::GatherDir
+    Git::NextVersion
+    Git::Describe
+    Git::Contributors
+    Git::Check
+    Git::Commit
+    Git::Tag
+    Git::Push
+    Git::CheckFor::MergeConflicts
+    Git::CheckFor::CorrectBranch
+    Git::Remote::Check
+    PromptIfStale
+    EnsurePrereqsInstalled
+);
+
+# confirms that no git-based plugins are running.
+sub assert_no_git
+{
+    my $tzil = shift;
+    my @git_plugins = grep { $_->meta->name =~ /Git(?!(?:hubMeta|Hub::Update))/ } @{$tzil->plugins};
+    cmp_deeply(\@git_plugins, [], 'no git-based plugins are running here');
+}
+
 # checks that all plugins in use are in the plugin bundle dist's runtime
 # requires list
 # - some plugins can be marked 'additional' - must be in recommended prereqs
